From f16c3b913802313c0032317ed48f1204dbb0f7ee Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jalil=20David=20Salam=C3=A9=20Messina?=
 <jalil.salame@gmail.com>
Date: Tue, 4 Mar 2025 09:44:23 +0100
Subject: [PATCH] fix(typo): typos corrected typ to typo

This is wrong for us (we use typ instead of type, not typo, because type
is a rust keyword).
---
 src/nsupdate.rs | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/nsupdate.rs b/src/nsupdate.rs
index 74397fa..eb0610c 100644
--- a/src/nsupdate.rs
+++ b/src/nsupdate.rs
@@ -37,14 +37,14 @@ impl std::fmt::Display for Action<'_> {
         match self {
             Action::Reassign { domain, to, ttl } => {
                 let ttl = ttl.as_secs();
-                let typ = match to {
+                let kind = match to {
                     IpAddr::V4(_) => "A",
                     IpAddr::V6(_) => "AAAA",
                 };
-                // Delete previous record of type `typ`
-                writeln!(f, "update delete {domain} {ttl} IN {typ}")?;
+                // Delete previous record of type `kind`
+                writeln!(f, "update delete {domain} {ttl} IN {kind}")?;
                 // Add record with new IP
-                writeln!(f, "update add    {domain} {ttl} IN {typ} {to}")
+                writeln!(f, "update add    {domain} {ttl} IN {kind} {to}")
             }
         }
     }
-- 
2.49.0